Entry

Struct Entry 

pub struct Entry { /* private fields */ }
A single entry in an error report, pairing an error message with an optional source-code Location.

Entries are produced by Report::new and accessed via Report::entries or Report::iter.

Examples

use errorstack::{ErrorStack, Report};

#[derive(thiserror::Error, ErrorStack, Debug)]
#[error("something broke")]
struct MyError {
    #[location]
    location: &'static std::panic::Location<'static>,
}

let report = Report::new(&MyError::new());
let messages: Vec<_> = report.iter().map(|e| e.message()).collect();
assert_eq!(messages, ["something broke"]);

Implementations

Source

impl Entry

pub fn message(&self) -> &str

Returns the display message for this entry.

pub fn location(&self) -> Option<&'static Location<'static>>

Returns the source-code location where this error was constructed, if the error implements location tracking.